==> vue-time-range-2.22.0.tgz: package/lib/index.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/time-range/vue';
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import TimeSpinner from '@opentinyvue/vue-time-spinner';
import Button from '@opentinyvue/vue-button';
import '@opentinyvue/vue-theme/time-range/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "TimeRange",
  emits: ["dodestroy", "pick", "select-range"],
  components: {
    TimeSpinner,
    TinyButton: Button
  },
  props: {
    emitter: Object
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    attrs: {
      "name": "tiny-zoom-in-top"
    },
    on: {
      "after-leave": function afterLeave($event) {
        return _vm.$emit("dodestroy");
      }
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.visible,
      expression: "state.visible"
    }],
    staticClass: "tiny-time-range tiny-time-range-picker tiny-picker-panel tiny-popper",
    class: _vm.state.popperClass
  }, [_c("div", {
    staticClass: "tiny-time-range-picker__content"
  }, [_c("div", {
    staticClass: "tiny-time-range-picker__cell"
  }, [_c("div", {
    staticClass: "tiny-time-range-picker__header"
  }, [_c("span", [_vm._v(_vm._s(_vm.t("ui.datepicker.startTime")))])]), _c("div", {
    staticClass: "tiny-time-range-picker__content-date"
  }, [_c("div", {
    staticClass: "tiny-time-range-picker__header-title"
  }, [_c("span", [_vm._v(_vm._s(_vm.t("ui.datepicker.hour")))]), _c("span", [_vm._v(_vm._s(_vm.t("ui.datepicker.minute")))]), _vm.state.showSeconds ? _c("span", [_vm._v(_vm._s(_vm.t("ui.datepicker.second")))]) : _vm._e()]), _c("div", {
    staticClass: "tiny-time-range-picker__body tiny-time-panel__content",
    class: {
      "has-seconds": _vm.state.showSeconds,
      "is-arrow": _vm.state.arrowControl
    }
  }, [_c("time-spinner", {
    ref: "minSpinner",
    attrs: {
      "show-seconds": _vm.state.showSeconds,
      "am-pm-mode": _vm.state.amPmMode,
      "end-date": _vm.state.maxDate,
      "arrow-control": _vm.state.arrowControl,
      "date": _vm.state.minDate
    },
    on: {
      "change": _vm.handleMinChange,
      "select-range": _vm.setMinSelectionRange
    }
  })], 1)])]), _c("div", {
    staticClass: "tiny-time-range-picker__cell"
  }, [_c("div", {
    staticClass: "tiny-time-range-picker__header"
  }, [_c("span", [_vm._v(_vm._s(_vm.t("ui.datepicker.endTime")))])]), _c("div", {
    staticClass: "tiny-time-range-picker__header-title"
  }, [_c("span", [_vm._v(_vm._s(_vm.t("ui.datepicker.hour")))]), _c("span", [_vm._v(_vm._s(_vm.t("ui.datepicker.minute")))]), _vm.state.showSeconds ? _c("span", [_vm._v(_vm._s(_vm.t("ui.datepicker.second")))]) : _vm._e()]), _c("div", {
    staticClass: "tiny-time-range-picker__body tiny-time-panel__content",
    class: {
      "has-seconds": _vm.state.showSeconds,
      "is-arrow": _vm.state.arrowControl
    }
  }, [_c("time-spinner", {
    ref: "maxSpinner",
    attrs: {
      "show-seconds": _vm.state.showSeconds,
      "am-pm-mode": _vm.state.amPmMode,
      "start-date": _vm.state.minDate,
      "arrow-control": _vm.state.arrowControl,
      "date": _vm.state.maxDate
    },
    on: {
      "change": _vm.handleMaxChange,
      "select-range": _vm.setMaxSelectionRange
    }
  })], 1)])]), _c("div", {
    staticClass: "tiny-time-range-picker__footer"
  }, [!_vm.state.showTimePickerRangeButton ? _c("tiny-button", {
    staticClass: "tiny-time-range-picker__btn cancel",
    on: {
      "click": function click($event) {
        return _vm.handleCancel();
      }
    }
  }, [_vm._v(" " + _vm._s(_vm.t("ui.datepicker.cancel")) + " ")]) : _vm._e(), _c("tiny-button", {
    class: {
      "tiny-time-range-picker__btn": !_vm.state.showTimePickerRangeButton,
      confirm: !_vm.state.disabled && !_vm.state.showTimePickerRangeButton
    },
    attrs: {
      "disabled": _vm.state.btnDisabled,
      "size": "small"
    },
    on: {
      "click": function click($event) {
        return _vm.handleConfirm();
      }
    }
  }, [_vm._v(" " + _vm._s(_vm.t("ui.datepicker.confirm")) + " ")])], 1)])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var TimeRange = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.22.0";
TimeRange.install = function(Vue) {
  Vue.component(TimeRange.name, TimeRange);
};
TimeRange.version = version;

export { TimeRange as default };

==> vue-time-range-2.22.1.tgz: package/lib/index.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/time-range/vue';
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import TimeSpinner from '@opentinyvue/vue-time-spinner';
import Button from '@opentinyvue/vue-button';
import '@opentinyvue/vue-theme/time-range/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "TimeRange",
  emits: ["dodestroy", "pick", "select-range"],
  components: {
    TimeSpinner,
    TinyButton: Button
  },
  props: {
    emitter: Object
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    attrs: {
      "name": "tiny-zoom-in-top"
    },
    on: {
      "after-leave": function afterLeave($event) {
        return _vm.$emit("dodestroy");
      }
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.visible,
      expression: "state.visible"
    }],
    staticClass: "tiny-time-range tiny-time-range-picker tiny-picker-panel tiny-popper",
    class: _vm.state.popperClass
  }, [_c("div", {
    staticClass: "tiny-time-range-picker__content"
  }, [_c("div", {
    staticClass: "tiny-time-range-picker__cell"
  }, [_c("div", {
    staticClass: "tiny-time-range-picker__header"
  }, [_c("span", [_vm._v(_vm._s(_vm.t("ui.datepicker.startTime")))])]), _c("div", {
    staticClass: "tiny-time-range-picker__content-date"
  }, [_c("div", {
    staticClass: "tiny-time-range-picker__header-title"
  }, [_c("span", [_vm._v(_vm._s(_vm.t("ui.datepicker.hour")))]), _c("span", [_vm._v(_vm._s(_vm.t("ui.datepicker.minute")))]), _vm.state.showSeconds ? _c("span", [_vm._v(_vm._s(_vm.t("ui.datepicker.second")))]) : _vm._e()]), _c("div", {
    staticClass: "tiny-time-range-picker__body tiny-time-panel__content",
    class: {
      "has-seconds": _vm.state.showSeconds,
      "is-arrow": _vm.state.arrowControl
    }
  }, [_c("time-spinner", {
    ref: "minSpinner",
    attrs: {
      "show-seconds": _vm.state.showSeconds,
      "am-pm-mode": _vm.state.amPmMode,
      "end-date": _vm.state.maxDate,
      "arrow-control": _vm.state.arrowControl,
      "date": _vm.state.minDate
    },
    on: {
      "change": _vm.handleMinChange,
      "select-range": _vm.setMinSelectionRange
    }
  })], 1)])]), _c("div", {
    staticClass: "tiny-time-range-picker__cell"
  }, [_c("div", {
    staticClass: "tiny-time-range-picker__header"
  }, [_c("span", [_vm._v(_vm._s(_vm.t("ui.datepicker.endTime")))])]), _c("div", {
    staticClass: "tiny-time-range-picker__header-title"
  }, [_c("span", [_vm._v(_vm._s(_vm.t("ui.datepicker.hour")))]), _c("span", [_vm._v(_vm._s(_vm.t("ui.datepicker.minute")))]), _vm.state.showSeconds ? _c("span", [_vm._v(_vm._s(_vm.t("ui.datepicker.second")))]) : _vm._e()]), _c("div", {
    staticClass: "tiny-time-range-picker__body tiny-time-panel__content",
    class: {
      "has-seconds": _vm.state.showSeconds,
      "is-arrow": _vm.state.arrowControl
    }
  }, [_c("time-spinner", {
    ref: "maxSpinner",
    attrs: {
      "show-seconds": _vm.state.showSeconds,
      "am-pm-mode": _vm.state.amPmMode,
      "start-date": _vm.state.minDate,
      "arrow-control": _vm.state.arrowControl,
      "date": _vm.state.maxDate
    },
    on: {
      "change": _vm.handleMaxChange,
      "select-range": _vm.setMaxSelectionRange
    }
  })], 1)])]), _c("div", {
    staticClass: "tiny-time-range-picker__footer"
  }, [!_vm.state.showTimePickerRangeButton ? _c("tiny-button", {
    staticClass: "tiny-time-range-picker__btn cancel",
    on: {
      "click": function click($event) {
        return _vm.handleCancel();
      }
    }
  }, [_vm._v(" " + _vm._s(_vm.t("ui.datepicker.cancel")) + " ")]) : _vm._e(), _c("tiny-button", {
    class: {
      "tiny-time-range-picker__btn": !_vm.state.showTimePickerRangeButton,
      confirm: !_vm.state.disabled && !_vm.state.showTimePickerRangeButton
    },
    attrs: {
      "disabled": _vm.state.btnDisabled,
      "size": "small"
    },
    on: {
      "click": function click($event) {
        return _vm.handleConfirm();
      }
    }
  }, [_vm._v(" " + _vm._s(_vm.t("ui.datepicker.confirm")) + " ")])], 1)])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var TimeRange = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.undefined";
TimeRange.install = function(Vue) {
  Vue.component(TimeRange.name, TimeRange);
};
TimeRange.version = version;

export { TimeRange as default };
